/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.gpstrackerexample;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.CoordinateSequence;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.geom.impl.CoordinateArraySequence;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.model.gps.GPSTracker;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Wytse Visser
 */
public class ExampleTracker extends GPSTracker {

    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.model.gps.AndroidTracker");

    public ExampleTracker() {
    }

    @Override
    protected Point getPosition() {
        Coordinate[] coordinates;
        try {
            coordinates = new Coordinate[]{toCoordinates(getRawContent())};
        } catch (IOException e) {
            LOGGER.warning("Could not connect to url. Position not updated.");
            coordinates = new Coordinate[]{new Coordinate(getMachine().getLongitude(), getMachine().getLatitude())};
        }
        CoordinateSequence coordSequence = new CoordinateArraySequence(coordinates);
        return new Point(coordSequence, new GeometryFactory());
    }

    private Coordinate toCoordinates(String rawContent) {
        String[] split = rawContent.split("/");
        double longitude = Double.parseDouble(split[0]);
        double latitude = Double.parseDouble(split[1]);
        return new Coordinate(longitude, latitude);
    }

    private String getRawContent() throws IOException {
        URL url = new URL("http://wytse.sites.djangoeurope.com/location/latest/");
        String content = "";
        String line;
        try (BufferedReader in = new BufferedReader(
                        new InputStreamReader(url.openStream()))) {
            while ((line = in.readLine()) != null) {
                content += line;
            }
        }
        return content;
    }
}
